# Table of Contents

- [embedding-report-in-sharepoint](<./embedding-report-in-sharepoint.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Embedding a Report in SharePoint](<./Embedding-a-Report-in-SharePoint.md>)
  - [Step 1: Get the Report Code](<./Embedding-a-Report-in-SharePoint/Step-1-Get-the-Report-Code.md>)
  - [Step 2: Embed the Report in SharePoint](<./Embedding-a-Report-in-SharePoint/Step-2-Embed-the-Report-in-SharePoint.md>)
